#include <magic.h>
#include "path.h"

// This is defined in magic.h.
inherit MAGIC_SPELL;

void setup() {
   // Set whether or not the casting time is fixed.
   set_fixed_time( 0 );
   // Set how many GP the spell costs.
   set_point_cost( 75 );
   // Set the power level of the spell.
   set_power_level( 45 );
   // Set what targets it is directed at.  0 means it's just 
   // cast, not at anything.
   set_directed( 0 );
   // The time in seconds to cast the spell.
   set_casting_time( 20 );

   // The spell's formal name.
   set_name( "Lady Tempesre's Dancing Dresses" );
   // The type of spell
   set_spell_type( "forces.defensive" );
   // The skill used to determine casting speed and some of the
   // power of the spell.
   set_skill_used( "magic.spells.defensive" );
   // Set this spell as requiring a beautiful blue dress
   // as a component.
   set_consumables( ({ "a beautiful blue dress" }) );
   // Set that there are no other needed components.
   set_needed( ({ }) );
   
   // Set ritual sets each of the stages for the spell.
   set_ritual( ({
      ({
         // These are the messages displayed.
         ({
            "You start to click your fingers.\n",
            "You start to click your fingers.\n",
            "$tp_name$ starts to click $tp_poss$ fingers.\n",
            "$tp_name$ starts to click $tp_poss$ fingers.\n",
         }),
         // This is the skill used for this stage
         "magic.methods.physical.dancing",
         // This is the neccessary bonus
         130,
         // The #check_room here tells the spellcasting code to 
         // call the function check_room at this stage.  If the 
         // function returns 0, the spell stops casting.  If 
         // it returns anything else, casting continues.
         ({"#check_room"})
      }),
      ({
         ({
            "You do a little dance with a beautiful blue dress.\n",
            "You do a little dance with a beautiful blue dress.\n",
            "$tp_name$ does a little dance with a beautiful blue dress\n",
            "$tp_name$ does a little dance with a beautiful blue dress\n",
         }),
         "magic.methods.physical.dancing",
         200,
         // Set this stage as consuming a beautiful blue dress.
         ({ "a beautiful blue dress" })
      }),
      ({
         ({
            "You throw the dress up into the air.\n",
            "You throw the dress up into the air.\n",
            "$tp_name$ throws the dress up into the air.\n",
            "$tp_name$ throws the dress up into the air.\n",
         }),
         "magic.methods.spiritual.summoning",
         180,
         ({ })
      }),
     }) );
} /* setup() */

/** 
 *
 *  This is the method called when the spell is successfully cast.  It handles
 *  the 'occult payload'
 *
 *  @param        caster          The caster of the spell
 *  @param        targets         The targets of the spell
 *  @param        bonus           The power of the spell
 *
 */
 
void spell_succeeded( object caster, object *targets, int bonus ) {  
  // Create a dancing dress NPC
  object ob = clone_object (CHARS + "dancing_dress");
  
  // Move it into the environment of the caster
  ob->move (environment (caster), "$N flutter$s around.", 
    "$N disappear$s with a pop.");
  // Add it as a protector of the caster.
  caster->add_protector (ob);  
} 

/** 
 *
 *  This is the method called when the spell fails to be cast.
 *
 *  @param        caster          The caster of the spell
 *  @param        targets         The targets of the spell
 *  @param        bonus           The power of the spell
 *
 */
 
void spell_failed( object caster, object *targets, int bonus ) {  
  tell_room ("Nothing happens in a most spectacular fashion.\n");
}

/** 
 *
 *  This method gets called at the first stage of spellcasting. 
 *
 *  @param        caster          The caster of the spell
 *  @param        targets         The targets of the spell
 *  @param        args            The details about the spell and stage
 *  @returns                      1 if casting should continue, 0 if it should not
 *
 */
 
int check_room(object caster, object *targets, class spell_argument args) {
  object env = environment (caster);
  
  // If there's no environment for the caster, bail out. 
  if (!env) {
    return 0;
  }
  
  // Call the function query_lady_tempesre_clothes_shop() on the 
  // environment.  If it returns 0, bail out.
  if (!env->query_lady_tempesre_clothes_shop()) {
    tell_object (caster, "This spell can only be cast in the boutique of "
      "Lady Tempesre.\n");
    return 0;
  }
  
  // We seem to be fine.
  return 1;
}

