#include <tasks.h>
#include <magic.h>
#include "path.h"

inherit MAGIC_SPELL;

void setup() {
     // Set whether or not the casting time is fixed.
   set_fixed_time( 1 );
   // Set how many GP the spell costs.
   set_point_cost( 60 );
   // Set the power level of the spell.
   set_power_level( 30 );
   // Set what targets it is directed at.  0 means it's just 
   // cast, not at anything.
   set_directed( SPELL_DIRECT_LIVING );
   // The time in seconds to cast the spell.
   set_casting_time( 15 );

   // The spell's formal name.
   set_name( "Lady Tempesre's Terrible Teleportation" );
   // The type of spell
   set_spell_type( "forces.offensive" );
   // The skill used to determine casting speed and some of the
   // power of the spell.
   set_skill_used( "magic.spells.misc" );
   // Set this spell as requiring no consumable components.
   set_consumables( ({ }) );
   // Set that there are no other needed components.
   set_needed( ({ }) );


   // Set ritual sets each of the stages for the spell.   
   set_ritual( ({
      ({
        // The messages to be displayed.
         ({
            "You form a claw with your hand.\n",
            "You form a claw with your hand.\n",
            "$tp_name$ forms a claw with $tp_poss$ hand.\n",
            "$tp_name$ forms a claw with $tp_poss$ hand.\n"
         }),
         // The skill to use for this stage
         "magic.methods.spiritual.conjuring",
         // The bonus needed for this stage.
         130,
         // No other action required.
         ({ })
      }),
      ({
         ({
            "You wiggle your fingers suggestively in the air.\n",
            "You wiggle your fingers suggestively in the air.\n",
            "$tp_name$ wiggles $tp_poss$ fingers suggestively in the air.\n",
            "$tp_name$ wiggles $tp_poss$ fingers suggestively in the air.\n"
         }),
         "magic.methods.physical.evoking",
         140,
         ({ })
      }),
      ({
         ({
            "You close one hand over the other.\n",
            "You close one hand over the other.\n",
            "$tp_name$ closes one hand over the other.\n",
            "$tp_name$ closes one hand over the other.\n",
         }),
         "magic.items.talisman",
         180,
         ({ })
      }),
      ({
         ({
            "You focus hard on your hands.\n",
            "You focus hard on your hands.\n",
            "$tp_name$ stares vacantly at $tp_poss$ hands.\n",
            "$tp_name$ stares vacantly at $tp_poss$ hands.\n"
         }),
         "magic.methods.mental.channeling",
         120,
         ({ })
      }),      
    ({
         ({
            "You clap your hands together.\n",
            "You clap your hands together.\n",
            "$tp_name$ claps $tp_poss$ hands together.\n",
            "$tp_name$ claps $tp_poss$ hands together.\n"
         }),
         "magic.methods.mental.channeling",
         120,
         ({ })
      }),      
     }) );
} /* setup() */

/** 
 *
 *  This is the method called when the spell is successfully cast.  It handles
 *  the 'occult payload'
 *
 *  @param        caster          The caster of the spell
 *  @param        targets         The targets of the spell
 *  @param        bonus           The power of the spell
 *
 */
 
 
void spell_succeeded( object caster, object *targets, int bonus ) {
  int ret;
  
  // Pass each target through the tasker.  Those that fail the test 
  // get sent into the lair of the beast.
  foreach (object target in targets) {
    ret = TASKER->perform_task (target, "magic.methods.spiritual.abjuring", 
      bonus, TM_FREE, 0);
      
    switch (ret) {
      case AWARD:
        tell_object (target, "%^BOLD%^%^YELLOW%^You feel more capable of "
          "resisting hostile magic!\n%^RESET%^");
      case SUCCEED:
        // Nothing happens.
        tell_object (target, "You feel the spell wash over you, but to no "
          "effect.\n");
        tell_room (environment (target), target->one_short() + " looks "
          "queasy for a moment, but nothing else seems to happen.", 
          ({ target }));
      break;
      case FAIL:
        tell_object (target, "You feel your stomach lurch...");
        target->move_with_look (ROOMS + "beast_lair", "$N appear$s with a "
          "pop.", "$N disappear$s with a pop.");         
    }
  }
} 

/** 
 *
 *  This is the method called when the spell fails to be cast.
 *
 *  @param        caster          The caster of the spell
 *  @param        targets         The targets of the spell
 *  @param        bonus           The power of the spell
 *
 */
void spell_failed(object caster, object * targets, int bonus) {
  // Fail the spell, MEET TEH BEEST
  tell_object (caster, "Bugger....\n");
  tell_room (environment (caster), caster->one_short() + " looks panicked for a "
    "brief moment.\n", ({ caster }));
  caster->move_with_look (ROOMS + "beast_lair", "$N appear$s with a "
    "pop.", "$N disappear$s with a pop.");         
}

